@@ -150,7 +150,7 @@ class BoundRow:
         if isinstance(penultimate, models.Model):
             try:
                 field = accessor.get_field(self.record)
-                display_fn = getattr(penultimate, "get_%s_display" % remainder, None)
+                display_fn = getattr(penultimate, f"get_{remainder}_display", None)
                 if getattr(field, "choices", ()) and display_fn:
                     value = display_fn()
                     remainder = None
@@ -311,15 +311,13 @@ class BoundRows:
 
     def __iter__(self):
         # Top pinned rows
-        for pinned_record in self.generator_pinned_row(self.pinned_data.get("top")):
-            yield pinned_record
+        yield from self.generator_pinned_row(self.pinned_data.get("top"))
 
         for record in self.data:
             yield BoundRow(record, table=self.table)
 
         # Bottom pinned rows
-        for pinned_record in self.generator_pinned_row(self.pinned_data.get("bottom")):
-            yield pinned_record
+        yield from self.generator_pinned_row(self.pinned_data.get("bottom"))
 
     def __len__(self):
         length = len(self.data)
